# Name:   Create-GuessGamePerformanceCounters.ps1
# Author: Micskei Zoltan
# Date:   2011.04.18.
# Desc:   Creates the performance counters for the ConsoleGuessGame application
# Param:  -Force    deletes the counters before creating them

param(    
    [switch] $Force
)

$CATEGORY_NAME = "ConsoleGuessGame"

# check that we have are admins
# NOTE: we actually do not need admin rights, just the appropriate level of PerformanceCounterPermissionAccess
$identity=[System.Security.Principal.WindowsIdentity]::GetCurrent()
$principal=new-object System.Security.Principal.WindowsPrincipal($identity)
$adminRole=[System.Security.Principal.WindowsBuiltInRole]::Administrator

if (! $principal.IsInRole($adminRole))
{
    Write-Warning "This script should be run as administrator!"
    exit 1
}

# check whether the category exists
$exists = [System.Diagnostics.PerformanceCounterCategory]::Exists($CATEGORY_NAME)
if ($exists -and ! $Force)
{
    Write-Warning "Category $CATEGORY_NAME exists, call the script with the -Force parameter to delete it before creating!"
    exit 2
}

# delete the category if force was specified
if ($Force -and $exists)
{   
    Write-Output "Deleting $CATEGORY_NAME category"          
    [System.Diagnostics.PerformanceCounterCategory]::Delete($CATEGORY_NAME);
}

#create counters
Write-Progress "Creating $CATEGORY_NAME category with counter"

$CounterDatas = New-Object System.Diagnostics.CounterCreationDataCollection;

$cdCounter1 = New-Object System.Diagnostics.CounterCreationData;
$cdCounter1.CounterName = "TotalGuesses";
$cdCounter1.CounterHelp = "Number of total guesses in the actual round."
$cdCounter1.CounterType = [System.Diagnostics.PerformanceCounterType]::NumberOfItems64

$cdCounter2 = New-Object System.Diagnostics.CounterCreationData
$cdCounter2.CounterName = "TotalFaultyGuesses"
$cdCounter2.CounterHelp = "Number of total faulty guesses in the actual round."
$cdCounter2.CounterType = [System.Diagnostics.PerformanceCounterType]::NumberOfItems64

$CounterDatas.Add($cdCounter1) > $null
$CounterDatas.Add($cdCounter2) > $null

[System.Diagnostics.PerformanceCounterCategory]::Create($CATEGORY_NAME, "Performance counters for the ConsoleGuessGame sample application", [System.Diagnostics.PerformanceCounterCategoryType]::MultiInstance, $CounterDatas) > $null

